﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace IGXamGrid.Core.ViewModels {
    public class TestData
         : ObservableCollection<IGSalesmanItem> {
        public TestData(int count = 50)
        {
            foreach (var item in IGSalesmanItem.GenerateData(count)) {
                this.Add(item);
            }
        }
    }

    public class IGSalesmanItem {
        public IGSalesmanItem()
        {
        }

        public int Index { get; set; }
        public string ImageName { get; set; }
        public string Territory { get; set; }
        public string LastName { get; set; }
        public string FirstName { get; set; }
        public int YearToDateSales { get; set; }
        public DateTime DateValue { get; set; }

        internal static string CreateLocalUri(string image)
        {
            return @"ms-appx:///Assets/People/" + image;
        }

        private static string CreateRemoteUri(string image)
        {
            return @"http://localhost/Assets/" + image;
        }

        static Random rnd = new Random();

        public static IGSalesmanItem GenerateItem(int index = 1)
        {

            String[] firstNames = {
            "Kyle",
            "Gina",
            "Irene",
            "Katie",
            "Michael",
            "Oscar",
            "Ralph",
            "Torrey",
            "William",
            "Bill",
            "Daniel",
            "Frank",
            "Brenda",
            "Danielle",
            "Fiona",
            "Howard",
            "Jack",
            "Larry",
            "Holly",
            "Jennifer",
            "Liz",
            "Pete",
            "Steve",
            "Vince",
            "Zeke"
    };

            String[] lastNames = {
            "Adams",
            "Crowley",
            "Ellis",
            "Gable",
            "Irvine",
            "Keefe",
            "Mendoza",
            "Owens",
            "Rooney",
            "Waddell",
            "Thomas",
            "Betts",
            "Doran",
            "Fitzgerald",
            "Holmes",
            "Jefferson",
            "Landry",
            "Newberry",
            "Perez",
            "Spencer",
            "Vargas",
            "Grimes",
            "Edwards",
            "Stark",
            "Cruise",
            "Fitz",
            "Chief",
            "Blanc",
            "Perry",
            "Stone",
            "Williams",
            "Lane",
            "Jobs"
    };

            String[] genders = {
            "GUY",
            "GIRL",
            "GIRL",
            "GIRL",
            "GUY",
            "GUY",
            "GUY",
            "GUY",
            "GUY",
            "GUY",
            "GUY",
            "GUY",
            "GIRL",
            "GIRL",
            "GIRL",
            "GUY",
            "GUY",
            "GUY",
            "GIRL",
            "GIRL",
            "GIRL",
            "GUY",
            "GUY",
            "GUY",
            "GUY"
    };

            String[] territories = {
            "Australia",
            "Canada",
            "Egypt",
            "Greece",
            "Italy",
            "Kenya",
            "Mexico",
            "Oman",
            "Qatar",
            "Sweden",
            "Uruguay",
            "Yemen",
            "Bulgaria",
            "Denmark",
            "France",
            "Hungary",
            "Japan",
            "Latvia",
            "Netherlands",
            "Portugal",
            "Russia",
            "Turkey",
            "Venezuela",
            "Zimbabwe"
    };
            IGSalesmanItem item = new IGSalesmanItem();
            int firstIndex = rnd.Next(firstNames.Length - 1);
            item.Index = index;
            item.FirstName = firstNames[firstIndex];
            item.LastName = lastNames[rnd.Next(lastNames.Length - 1)];


            int randomIndex = rnd.Next(firstNames.Length - 1);
            if (randomIndex == 0)
                randomIndex = 1;

            string number = randomIndex.ToString();
            if (randomIndex < 10)
                number = "0" + number;
            item.ImageName = CreateLocalUri(genders[firstIndex] + number + ".png");
            item.Territory = territories[rnd.Next(territories.Length - 1)];
            item.YearToDateSales = rnd.Next(500);

            item.DateValue = DateTime.Now.AddDays(rnd.Next(500));

            return item;

        }

        public static List<IGSalesmanItem> GenerateData(int count)
        {
            List<IGSalesmanItem> items = new List<IGSalesmanItem>();
            for (int i = 1; i < count + 1; i++) {
                items.Add(IGSalesmanItem.GenerateItem(i));
            }

            return items;
        }
    }
}
